@@ -38,14 +38,14 @@ def _get_mysql_uri(port: Optional[int] = None):
 
     credentials = _get_credentials()
     if port:
-        return "mysql+pymysql://%s:%s@%s:%s/%s?charset=utf8mb4" % (
+        return "mysql+pymysql://%s:%s@%s:%s/%s?charset=utf8mb4&binary_prefix=true" % (
             credentials["mysqlUser"],
             credentials["mysqlPassword"],
             "127.0.0.1",
             str(port),
             credentials["mysqlDB"],
         )
-    return "mysql+pymysql://%s:%s@%s/%s?charset=utf8mb4" % (
+    return "mysql+pymysql://%s:%s@%s/%s?charset=utf8mb4&binary_prefix=true" % (
         credentials["mysqlUser"],
         credentials["mysqlPassword"],
         credentials["mysqlHost"],
