@@ -24,7 +24,7 @@ class IPOOutboxResourceSchema(Schema):
     updated_at = fields.DateTime()
 
     @pre_load
-    def convert_string_to_datetime(self, in_data):
+    def convert_string_to_datetime(self, in_data, **kwargs):
         date_fields = ['ipo_date']
 
         in_data = pre_load_date_fields(
